@@ -266,11 +266,11 @@ class FeatureMapConsolidator(nn.Module):
 
         self.final_dim_out = dim + (sum(dim_outs) if len(dim_outs) > 0 else 0)
 
-    def resize_fmaps(self, fmaps, target_size):
-        return [F.interpolate(fmap, (fmap.shape[-3], target_size, target_size)) for fmap in fmaps]
+    def resize_fmaps(self, fmaps, height, width):
+        return [F.interpolate(fmap, (fmap.shape[-3], height, width)) for fmap in fmaps]
 
     def forward(self, x, fmaps = None):
-        target_size = x.shape[-1]
+        target_height, target_width = x.shape[-2:]
 
         fmaps = default(fmaps, tuple())
 
@@ -278,14 +278,14 @@ class FeatureMapConsolidator(nn.Module):
             return x
 
         if self.resize_fmap_before:
-            fmaps = self.resize_fmaps(fmaps, target_size)
+            fmaps = self.resize_fmaps(fmaps, target_height, target_width)
 
         outs = []
         for fmap, conv in zip(fmaps, self.fmap_convs):
             outs.append(conv(fmap))
 
         if self.resize_fmap_before:
-            outs = self.resize_fmaps(outs, target_size)
+            outs = self.resize_fmaps(outs, target_height, target_width)
 
         return torch.cat((x, *outs), dim = 1)
 
@@ -599,9 +599,9 @@ class NestedResidualUnet(nn.Module):
 
         layers = len(self.ups)
 
-        assert h == w, 'only works with square images'
-        assert divisible_by(h, 2 ** len(self.ups)), f'dimension {h} must be divisible by {2 ** layers} ({layers} layers in nested unet)'
-        assert (h % (2 ** self.depth)) == 0, 'the unet has too much depth for the image being passed in'
+        for dim_name, size in (('height', h), ('width', w)):
+            assert divisible_by(size, 2 ** layers), f'{dim_name} dimension {size} must be divisible by {2 ** layers} ({layers} layers in nested unet)'
+            assert (size % (2 ** self.depth)) == 0, f'the unet has too much depth for the image {dim_name} ({size}) being passed in'
 
         # hiddens
 
